? systypeslocation.patch
? src/aclheader.patch
Index: include/config.h.in
===================================================================
RCS file: /cvsroot/squid/squid/include/config.h.in,v
retrieving revision 1.5
diff -u -r1.5 config.h.in
--- include/config.h.in	2001/02/25 22:02:55	1.5
+++ include/config.h.in	2001/03/10 04:48:49
@@ -183,10 +183,4 @@
 #define squid_srandom srand
 #endif
 
-/* 32 bit integer compatability */
-#include "squid_types.h"
-#define num32 int32_t
-#define u_num32 u_int32_t
-
-
 #endif /* _CONFIG_H_ */
Index: include/md5.h
===================================================================
RCS file: /cvsroot/squid/squid/include/md5.h,v
retrieving revision 1.3
diff -u -r1.3 md5.h
--- include/md5.h	2001/01/31 22:20:26	1.3
+++ include/md5.h	2001/03/10 04:48:49
@@ -29,10 +29,12 @@
  * documentation and/or software.
  */
 
+#include "squid_types.h"
+
 /* MD5 context. */
 typedef struct {
-    u_num32 state[4];		/* state (ABCD) */
-    u_num32 count[2];		/* number of bits, modulo 2^64 (lsb first) */
+    u_int32_t state[4];		/* state (ABCD) */
+    u_int32_t count[2];		/* number of bits, modulo 2^64 (lsb first) */
     unsigned char buffer[64];	/* input buffer */
 } MD5_CTX;
 
Index: src/squid.h
===================================================================
RCS file: /cvsroot/squid/squid/src/squid.h,v
retrieving revision 1.10
diff -u -r1.10 squid.h
--- src/squid.h	2001/02/23 05:51:08	1.10
+++ src/squid.h	2001/03/10 04:48:58
@@ -89,6 +89,12 @@
 #define assert(EX)  ((EX)?((void)0):xassert("EX", __FILE__, __LINE__))
 #endif
 
+
+/* 32 bit integer compatability */
+#include "squid_types.h"
+#define num32 int32_t
+#define u_num32 u_int32_t
+
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif


Index: lib/md5.c
===================================================================
RCS file: /cvsroot/squid/squid/lib/md5.c,v
retrieving revision 1.3
diff -u -r1.3 md5.c
--- lib/md5.c	2001/01/31 22:20:27	1.3
+++ lib/md5.c	2001/03/10 04:48:51
@@ -63,9 +63,9 @@
 #define S43 15
 #define S44 21
 
-static void MD5Transform(u_num32[4], const unsigned char[64]);
-static void Encode(unsigned char *, u_num32 *, unsigned int);
-static void Decode(u_num32 *, const unsigned char *, unsigned int);
+static void MD5Transform(u_int32_t[4], const unsigned char[64]);
+static void Encode(unsigned char *, u_int32_t *, unsigned int);
+static void Decode(u_int32_t *, const unsigned char *, unsigned int);
 
 #if HAVE_MEMCPY
 #define MD5_memcpy(to,from,count) memcpy(to,from,count)
@@ -104,22 +104,22 @@
  * separate from addition to prevent recomputation.
  */
 #define FF(a, b, c, d, x, s, ac) { \
- (a) += F ((b), (c), (d)) + (x) + (u_num32)(ac); \
+ (a) += F ((b), (c), (d)) + (x) + (u_int32_t)(ac); \
  (a) = ROTATE_LEFT ((a), (s)); \
  (a) += (b); \
   }
 #define GG(a, b, c, d, x, s, ac) { \
- (a) += G ((b), (c), (d)) + (x) + (u_num32)(ac); \
+ (a) += G ((b), (c), (d)) + (x) + (u_int32_t)(ac); \
  (a) = ROTATE_LEFT ((a), (s)); \
  (a) += (b); \
   }
 #define HH(a, b, c, d, x, s, ac) { \
- (a) += H ((b), (c), (d)) + (x) + (u_num32)(ac); \
+ (a) += H ((b), (c), (d)) + (x) + (u_int32_t)(ac); \
  (a) = ROTATE_LEFT ((a), (s)); \
  (a) += (b); \
   }
 #define II(a, b, c, d, x, s, ac) { \
- (a) += I ((b), (c), (d)) + (x) + (u_num32)(ac); \
+ (a) += I ((b), (c), (d)) + (x) + (u_int32_t)(ac); \
  (a) = ROTATE_LEFT ((a), (s)); \
  (a) += (b); \
   }
@@ -153,10 +153,10 @@
     index = (unsigned int) ((context->count[0] >> 3) & 0x3F);
 
     /* Update number of bits */
-    if ((context->count[0] += ((u_num32) inputLen << 3))
-	< ((u_num32) inputLen << 3))
+    if ((context->count[0] += ((u_int32_t) inputLen << 3))
+	< ((u_int32_t) inputLen << 3))
 	context->count[1]++;
-    context->count[1] += ((u_num32) inputLen >> 29);
+    context->count[1] += ((u_int32_t) inputLen >> 29);
 
     partLen = 64 - index;
 
@@ -213,9 +213,9 @@
  * MD5 basic transformation. Transforms state based on block.
  */
 static void
-MD5Transform(u_num32 state[4], const unsigned char block[64])
+MD5Transform(u_int32_t state[4], const unsigned char block[64])
 {
-    u_num32 a = state[0], b = state[1], c = state[2], d = state[3], x[16];
+    u_int32_t a = state[0], b = state[1], c = state[2], d = state[3], x[16];
 
     Decode(x, block, 64);
 
@@ -303,11 +303,11 @@
 }
 
 /*
  * Encodes input (u_num32) into output (unsigned char). Assumes len is a
  * multiple of 4.
  */
 static void
-Encode(unsigned char *output, u_num32 * input, unsigned int len)
+Encode(unsigned char *output, u_int32_t * input, unsigned int len)
 {
     unsigned int i, j;
 
@@ -320,17 +320,17 @@
 }
 
 /*
  * Decodes input (unsigned char) into output (u_num32). Assumes len is a
  * multiple of 4.
  */
 static void
-Decode(u_num32 * output, const unsigned char *input, unsigned int len)
+Decode(u_int32_t * output, const unsigned char *input, unsigned int len)
 {
     unsigned int i, j;
 
     for (i = 0, j = 0; j < len; i++, j += 4)
-	output[i] = ((u_num32) input[j]) | (((u_num32) input[j + 1]) << 8) |
-	    (((u_num32) input[j + 2]) << 16) | (((u_num32) input[j + 3]) << 24);
+	output[i] = ((u_int32_t) input[j]) | (((u_int32_t) input[j + 1]) << 8) |
+	    (((u_int32_t) input[j + 2]) << 16) | (((u_int32_t) input[j + 3]) << 24);
 }
 
 #if !HAVE_MEMCPY
@@ -303,11 +303,11 @@
 
 /*
- * Encodes input (u_num32) into output (unsigned char). Assumes len is a
+ * Encodes input (u_int32_t) into output (unsigned char). Assumes len is a
  * multiple of 4.
  */
@@ -320,17 +320,17 @@
 
 /*
- * Decodes input (unsigned char) into output (u_num32). Assumes len is a
+ * Decodes input (unsigned char) into output (u_int32_t). Assumes len is a
  * multiple of 4.
  */